Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Job ¶
type Job struct {
Title string `json:"title"`
URL string `json:"url"`
HTTPMethod string `json:"httpMethod"`
Headers map[string]interface{} `json:"headers"`
Frequency int `json:"frequency"`
Success bool `json:"passing"`
ExpectedResponse Response `json:"expectedResponse"`
RequestBody map[string]interface{} `json:"requestBody"`
}
func (Job) HandleResponse ¶
verify if the request got the expected result and format the data for writing to the database
func (Job) Schedule ¶
func (j Job) Schedule(recChan chan<- datastore.Record, blocker chan struct{}, n notification.Notification)
Create a ticker for a job to trigger it periodically
Click to show internal directories.
Click to hide internal directories.